@@ -179,7 +179,7 @@ KoStore* KoStore::createStore(QWidget* window, const KUrl& url, Mode mode, const
     default:
         kWarning(s_area) << "Unsupported backend requested for KoStore (KUrl) : " << backend;
         KMessageBox::sorry(window,
-                           i18n("The directory mode is not supported for remote locations."),
+                           i18n("The folder mode is not supported for remote locations."),
                            i18n("KOffice Storage"));
         return 0;
     }
@@ -512,7 +512,7 @@ bool KoStore::extractFile(const QString &srcName, QIODevice &buffer)
 
 QStringList KoStore::addLocalDirectory(const QString &dirPath, const QString &destName)
 {
-    QString dot = ".";
+    QString dot('.');
     QString dotdot = "..";
     QStringList content;
 
@@ -562,7 +562,7 @@ QString KoStore::toExternalNaming(const QString & _internalNaming) const
         return expandEncodedDirectory(currentPath()) + MAINNAME;
 
     QString intern;
-    if (_internalNaming.startsWith("tar:/"))     // absolute reference
+    if (_internalNaming.startsWith(QLatin1String("tar:/")))     // absolute reference
         intern = _internalNaming.mid(5);   // remove protocol
     else
         intern = currentPath() + _internalNaming;
